[−][src]Enum http_sig::PseudoHeader
Pseudo-headers are used to incorporate additional information into a HTTP signature for which there is no corresponding HTTP header.
They are described as "special headers" in the draft specification: https://tools.ietf.org/id/draft-cavage-http-signatures-12.html#canonicalization
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The (request-target) pseudo-header is constructed by joining the lower-cased
request method (get, post, etc.) and the request path (/some/page?foo=1)
with a single space character.
For example:
get /index.html
Methods
impl PseudoHeader[src]