HttpSignatureSign

Trait HttpSignatureSign 

pub trait HttpSignatureSign:
    Debug
    + Send
    + Sync
    + 'static {
    // Required method
    fn http_sign(&self, bytes_to_sign: &[u8]) -> String;
}
Implements the signing half of an HTTP signature algorithm. For symmetric algorithms the same type implements both signing and verification.

Required Methods

fn http_sign(&self, bytes_to_sign: &[u8]) -> String

Returns the encoded signature, ready for inclusion in the HTTP Authorization header. For all currently supported signature schemes, the encoding is specified to be base64.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors