HttpSignatureVerify

Trait HttpSignatureVerify 

pub trait HttpSignatureVerify:
    Debug
    + Send
    + Sync
    + 'static {
    // Required method
    fn http_verify(&self, bytes_to_verify: &[u8], signature: &str) -> bool;
}
Implements the verification half of an HTTP signature algorithm. For symmetric algorithms the same type implements both signing and verification.

Required Methods

fn http_verify(&self, bytes_to_verify: &[u8], signature: &str) -> bool

Returns true if the signature is valid for the provided content. The implementation should be sure to perform any comparisons in constant time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors