pub trait DigestProvider:
Debug
+ Sync
+ 'static {
// Required method
fn provide_digest(&self, name: &str) -> Option<Box<dyn HttpDigest>>;
}Expand description
The verification process will use this trait to find the appropriate digest algorithm to use when verifying the body of a request.
Unless explicitly overridden, the DefaultDigestProvider will be used
Required Methods
Sourcefn provide_digest(&self, name: &str) -> Option<Box<dyn HttpDigest>>
fn provide_digest(&self, name: &str) -> Option<Box<dyn HttpDigest>>
Returns a digest algorithm for the given name, or None if the algorithm is not
recognised by the provider.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".