[−][src]Trait http_sig::HttpSignature
Implementations of this trait correspond to signature algorithms listed here: https://tools.ietf.org/id/draft-cavage-http-signatures-12.html#hsa-registry
If the HTTP signatures draft is accepted, these will be moved to a registry managed by the IANA.
Required methods
fn name(&self) -> &str
Must return the name exactly as specified in the above list of HTTP signature algorithms.
fn http_sign(&self, bytes_to_sign: &[u8]) -> String
Returns the encoded signature, ready for inclusion in the HTTP Authorization header. For all currently supported signature schemes, the encoding is specified to be base64.